from library_interp_extrap import *
from compute_density import compute_density
import os
import shutil
import gzip
#This fonction generate a restart interpolated verticaly on the output grid
###########
#Arguments#
###########
#filein: input restart file
#fmask: input mask corresponding to the input file 
#ex: fmask="/esnas/autosubmit/con_files/mesh_mask_nemo.nemovar_O1L42.nc"
#resout: output resolution ex: resout="1L75"
#versout: corresponding model version ex:versout="Ec3.2"


#  Input arguments
filein=sys.argv[1]
fmask=sys.argv[2]
resout=sys.argv[3]
versout=sys.argv[4]

#go in the working directory
#workdir="/scratch/Earth/"+os.environ["USER"]+"/restart_"+resout+"_"+versout
#if (not os.path.isdir(workdir)):
#    os.makedirs(workdir)
#os.chdir(workdir)

# mask file describing the output grid
fmaskout="/esnas/autosubmit/con_files/mesh_mask_nemo."+versout+"_O"+resout+".nc"

dirout="/esnas/releases/ic/ocean/ORCA"+resout+"/s4"
#copy the file from the /esnas into the 
dirin,fileinloc=os.path.split(filein)
if dirin!="":
    shutil.copy(filein, fileinloc)
    
#copy the mask from the /esnas into the 
dirmask,fmaskloc=os.path.split(fmask)
if dirmask!="":
    shutil.copy(fmask, fmaskloc)

#temporary output file
fileout=filein.replace(".nc","_new.nc")

#define the variable name of longitude latitude depth
#to be copied from the mask
vardim=["nav_lon", "nav_lat", "nav_lev"]

#variable copied with no interpolation
varnointerp=["time_counter", "rdt", "slim", "rdttra1", "kt", "ndastp", "adatrj"]

lstfieldout=[]

#Open the output file
fin=nc(fileinloc, "r")
fmout=nc(fmaskout, "r")
fmin=nc(fmaskloc, "r")
fout=nc(fileout, "w")
nlev=fmout.dimensions["z"].size

#copy all th dimension for fin except the level
for name, dimension in fin.dimensions.iteritems():
    if name != "z":
        fout.createDimension(str(name), len(dimension) if not dimension.isunlimited() else None)
#create the level dimension
fout.createDimension("z", nlev)

#write the variable corresponding to the dimension (from the input mask)
for name in vardim:
    variable=fmout.variables[name]
    fout.createVariable(name, variable.datatype, variable.dimensions)
    fout.variables[name][:]=variable[:]
    
            
listdens=[]
listdens_varname=[]
for varin, variable in fin.variables.iteritems():
    print(varin)
    #take out the variable nav_lev, lon ,lat
    if not(varin in vardim):
        #for the variable which no need interpolation copy them
        if varin in varnointerp:
            var=fout.createVariable(varin, variable.datatype, variable.dimensions)
            var[:]=variable[:]
        else:
            #perform the interpolation vertical y horizontal
            fieldout=vertinterp_extrap(fin, varin, fmin, fmout)
            #add the temporal dimension
            shapeout=(1,)+fieldout.shape
            fieldout.shape=shapeout
            if varin in ["tn","sn"]:
                listdens.append(fieldout)
                listdens_varname.append(varin)
            #put 0 for mask value (only by converting from ma into np array)
            fieldout=np.array(fieldout)
            var=fout.createVariable(varin, variable.datatype, variable.dimensions)
            var[:]=fieldout
 

#get temperature
ptemp=listdens[listdens_varname.index("tn")]
#get salinity
psal=listdens[listdens_varname.index("sn")]

print("rhop")
rhop=compute_density(ptemp, psal) 
#convert into numpy array (0 instead of mask)
rhop=np.array(rhop)
#write density into the output file
var=fout.createVariable("rhop", 
                        fin.variables["tn"].datatype, 
                        fin.variables["tn"].dimensions)


var[:]=rhop

           
fin.close()
fout.close()
fmin.close()
fmout.close()

#gzip the files
with open(fileout, 'rb') as f_in, gzip.open(fileout+'.gz', 'wb') as f_out:
    shutil.copyfileobj(f_in, f_out)

#copy the output file into /esnas
shutil.copy(fileout+'.gz', os.path.join(dirout,fileinloc+'.gz'))
print("the output restart has been created and copied into:")
print(os.path.join(dirout,fileinloc+'.gz'))
